#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark-pandoc
version:              0.3
visibility:           public
id:                   commonmark-pandoc-0.3-9JxiawTXA0IDtrI39lNdhw
key:                  commonmark-pandoc-0.3-9JxiawTXA0IDtrI39lNdhw
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Bridge between commonmark and pandoc AST.
description:
    This library provides typeclasses for rendering
    commonmark to Pandoc types.

category:             Text
abi:                  9b634b08c2eacbb74a73d960b1ca5547
exposed:              True
exposed-modules:      Commonmark.Pandoc
import-dirs:          /usr/lib/ghc-9.6.6/site-local/commonmark-pandoc-0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/commonmark-pandoc-0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/commonmark-pandoc-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark-pandoc
hs-libraries:         HScommonmark-pandoc-0.3-9JxiawTXA0IDtrI39lNdhw
depends:
    base-4.18.2.1 commonmark-0.3-43qQWvvh7VR35iUXx0jt03
    commonmark-extensions-0.2.7.1-70L2DCwwjF9BPVIKZdtRSB
    pandoc-types-1.23.1.2-9jgLsuZngFN3JhSzLXhKOt text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-pandoc/html/commonmark-pandoc.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-pandoc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

